"""songbox API Client Exceptions"""

from typing import Optional


class songboxError(Exception):
    """Base exception for all songbox API errors."""
    pass


class APIError(songboxError):
    """Exception raised when the API returns an error response.
    
    Args:
        message: Error message
        status_code: HTTP status code
        response_data: Raw response data from the API
    """
    
    def __init__(
        self, 
        message: str, 
        status_code: Optional[int] = None, 
        response_data: Optional[dict] = None
    ):
        super().__init__(message)
        self.message = message
        self.status_code = status_code
        self.response_data = response_data or {}
    
    def __str__(self) -> str:
        if self.status_code:
            return f"API Error {self.status_code}: {self.message}"
        return f"API Error: {self.message}"


class AuthenticationError(songboxError):
    """Exception raised for authentication-related errors."""
    pass


class RateLimitError(APIError):
    """Exception raised when rate limit is exceeded."""
    pass


class NotFoundError(APIError):
    """Exception raised when a resource is not found (404)."""
    pass


class ValidationError(songboxError):
    """Exception raised for input validation errors."""
    pass